KevyOpenOptions class final

Options for kevy_open_with. Start from KEVY_OPEN_OPTIONS_INIT (the exact defaults kevy_open uses) and override what you need. rewrite_pct 0 turns the growth rule off (as in Redis); rewrite_bytes / rewrite_interval_secs are the absolute-size and staleness triggers (0 = off). fsync: 0 everysec, 1 always, 2 no.

Inheritance
Implemented types
Available extensions

Constructors

KevyOpenOptions()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
fsync int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rewrite_bytes int
getter/setter pair
rewrite_interval_secs int
getter/setter pair
rewrite_min_size int
getter/setter pair
rewrite_pct int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shards int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited